@@ -10,6 +10,7 @@ from robotcode.core.language import language_id
 from robotcode.core.lsp.types import FoldingRange
 from robotcode.core.text_document import TextDocument
 from robotcode.core.utils.logging import LoggingDescriptor
+from robotcode.robot.utils import get_robot_version
 from robotcode.robot.utils.visitor import Visitor
 
 from .protocol_part import RobotLanguageServerProtocolPart
@@ -17,6 +18,9 @@ from .protocol_part import RobotLanguageServerProtocolPart
 if TYPE_CHECKING:
     from ..protocol import RobotLanguageServerProtocol
 
+if get_robot_version() >= (5, 0):
+    from robot.parsing.model.blocks import Try, While
+
 
 class _Visitor(Visitor):
     def __init__(self, parent: RobotFoldingRangeProtocolPart) -> None:
@@ -54,18 +58,18 @@ class _Visitor(Visitor):
         if not self.line_folding_only:
             self.result.append(
                 FoldingRange(
-                    start_line=start_node.lineno - 1,
-                    end_line=end_node.end_lineno - 1 if end_node.end_lineno is not None else end_node.lineno - 1,
-                    start_character=start_node.col_offset if not self.line_folding_only else None,
-                    end_character=end_node.end_col_offset if not self.line_folding_only else None,
+                    start_line=start_node.lineno - 1,  # type: ignore
+                    end_line=end_node.end_lineno - 1 if end_node.end_lineno is not None else end_node.lineno - 1,  # type: ignore
+                    start_character=start_node.col_offset if not self.line_folding_only else None,  # type: ignore
+                    end_character=end_node.end_col_offset if not self.line_folding_only else None,  # type: ignore
                     kind=kind,
                 )
             )
         else:
             self.result.append(
                 FoldingRange(
-                    start_line=start_node.lineno - 1,
-                    end_line=end_node.end_lineno - 1 if end_node.end_lineno is not None else end_node.lineno - 1,
+                    start_line=start_node.lineno - 1,  # type: ignore
+                    end_line=end_node.end_lineno - 1 if end_node.end_lineno is not None else end_node.lineno - 1,  # type: ignore
                     kind=kind,
                 )
             )
@@ -117,6 +121,19 @@ class _Visitor(Visitor):
         if node.type == "IF":
             self.current_if.remove(node)
 
+    if get_robot_version() >= (5, 0):
+
+        def visit_While(self, node: While) -> None:  # noqa: N802
+            self.__append(node, kind="while")
+            self.generic_visit(node)
+
+        def visit_Try(self, node: Try) -> None:  # noqa: N802
+            self.__append(node, kind="try", end_node=node.body[-1] if node.body else None)
+            self.generic_visit(node)
+
+
+#
+
 
 class RobotFoldingRangeProtocolPart(RobotLanguageServerProtocolPart):
     _logger = LoggingDescriptor()
